# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'LedgerAzureadBasedServicePrincipalArgs',
    'LedgerCertificateBasedSecurityPrincipalArgs',
]

@pulumi.input_type
class LedgerAzureadBasedServicePrincipalArgs:
    def __init__(__self__, *,
                 ledger_role_name: pulumi.Input[str],
                 principal_id: pulumi.Input[str],
                 tenant_id: pulumi.Input[str]):
        """
        :param pulumi.Input[str] ledger_role_name: Specifies the Ledger Role to grant this AzureAD Service Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        :param pulumi.Input[str] principal_id: Specifies the Principal ID of the AzureAD Service Principal.
        :param pulumi.Input[str] tenant_id: Specifies the Tenant ID for this AzureAD Service Principal.
        """
        LedgerAzureadBasedServicePrincipalArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            ledger_role_name=ledger_role_name,
            principal_id=principal_id,
            tenant_id=tenant_id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             ledger_role_name: Optional[pulumi.Input[str]] = None,
             principal_id: Optional[pulumi.Input[str]] = None,
             tenant_id: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if ledger_role_name is None and 'ledgerRoleName' in kwargs:
            ledger_role_name = kwargs['ledgerRoleName']
        if ledger_role_name is None:
            raise TypeError("Missing 'ledger_role_name' argument")
        if principal_id is None and 'principalId' in kwargs:
            principal_id = kwargs['principalId']
        if principal_id is None:
            raise TypeError("Missing 'principal_id' argument")
        if tenant_id is None and 'tenantId' in kwargs:
            tenant_id = kwargs['tenantId']
        if tenant_id is None:
            raise TypeError("Missing 'tenant_id' argument")

        _setter("ledger_role_name", ledger_role_name)
        _setter("principal_id", principal_id)
        _setter("tenant_id", tenant_id)

    @property
    @pulumi.getter(name="ledgerRoleName")
    def ledger_role_name(self) -> pulumi.Input[str]:
        """
        Specifies the Ledger Role to grant this AzureAD Service Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        return pulumi.get(self, "ledger_role_name")

    @ledger_role_name.setter
    def ledger_role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "ledger_role_name", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> pulumi.Input[str]:
        """
        Specifies the Principal ID of the AzureAD Service Principal.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Input[str]:
        """
        Specifies the Tenant ID for this AzureAD Service Principal.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "tenant_id", value)


@pulumi.input_type
class LedgerCertificateBasedSecurityPrincipalArgs:
    def __init__(__self__, *,
                 ledger_role_name: pulumi.Input[str],
                 pem_public_key: pulumi.Input[str]):
        """
        :param pulumi.Input[str] ledger_role_name: Specifies the Ledger Role to grant this Certificate Security Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        :param pulumi.Input[str] pem_public_key: The public key, in PEM format, of the certificate used by this identity to authenticate with the Confidential Ledger.
        """
        LedgerCertificateBasedSecurityPrincipalArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            ledger_role_name=ledger_role_name,
            pem_public_key=pem_public_key,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             ledger_role_name: Optional[pulumi.Input[str]] = None,
             pem_public_key: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if ledger_role_name is None and 'ledgerRoleName' in kwargs:
            ledger_role_name = kwargs['ledgerRoleName']
        if ledger_role_name is None:
            raise TypeError("Missing 'ledger_role_name' argument")
        if pem_public_key is None and 'pemPublicKey' in kwargs:
            pem_public_key = kwargs['pemPublicKey']
        if pem_public_key is None:
            raise TypeError("Missing 'pem_public_key' argument")

        _setter("ledger_role_name", ledger_role_name)
        _setter("pem_public_key", pem_public_key)

    @property
    @pulumi.getter(name="ledgerRoleName")
    def ledger_role_name(self) -> pulumi.Input[str]:
        """
        Specifies the Ledger Role to grant this Certificate Security Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        return pulumi.get(self, "ledger_role_name")

    @ledger_role_name.setter
    def ledger_role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "ledger_role_name", value)

    @property
    @pulumi.getter(name="pemPublicKey")
    def pem_public_key(self) -> pulumi.Input[str]:
        """
        The public key, in PEM format, of the certificate used by this identity to authenticate with the Confidential Ledger.
        """
        return pulumi.get(self, "pem_public_key")

    @pem_public_key.setter
    def pem_public_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "pem_public_key", value)


