# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'CaaRecordRecordArgs',
    'MxRecordRecordArgs',
    'SrvRecordRecordArgs',
    'TxtRecordRecordArgs',
    'ZoneSoaRecordArgs',
]

@pulumi.input_type
class CaaRecordRecordArgs:
    def __init__(__self__, *,
                 flags: pulumi.Input[int],
                 tag: pulumi.Input[str],
                 value: pulumi.Input[str]):
        """
        :param pulumi.Input[int] flags: Extensible CAA flags, currently only 1 is implemented to set the issuer critical flag.
        :param pulumi.Input[str] tag: A property tag, options are `issue`, `issuewild` and `iodef`.
        :param pulumi.Input[str] value: A property value such as a registrar domain.
        """
        CaaRecordRecordArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            flags=flags,
            tag=tag,
            value=value,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             flags: Optional[pulumi.Input[int]] = None,
             tag: Optional[pulumi.Input[str]] = None,
             value: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if flags is None:
            raise TypeError("Missing 'flags' argument")
        if tag is None:
            raise TypeError("Missing 'tag' argument")
        if value is None:
            raise TypeError("Missing 'value' argument")

        _setter("flags", flags)
        _setter("tag", tag)
        _setter("value", value)

    @property
    @pulumi.getter
    def flags(self) -> pulumi.Input[int]:
        """
        Extensible CAA flags, currently only 1 is implemented to set the issuer critical flag.
        """
        return pulumi.get(self, "flags")

    @flags.setter
    def flags(self, value: pulumi.Input[int]):
        pulumi.set(self, "flags", value)

    @property
    @pulumi.getter
    def tag(self) -> pulumi.Input[str]:
        """
        A property tag, options are `issue`, `issuewild` and `iodef`.
        """
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: pulumi.Input[str]):
        pulumi.set(self, "tag", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        A property value such as a registrar domain.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class MxRecordRecordArgs:
    def __init__(__self__, *,
                 exchange: pulumi.Input[str],
                 preference: pulumi.Input[str]):
        """
        :param pulumi.Input[str] exchange: The mail server responsible for the domain covered by the MX record.
        :param pulumi.Input[str] preference: String representing the "preference” value of the MX records. Records with lower preference value take priority.
        """
        MxRecordRecordArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            exchange=exchange,
            preference=preference,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             exchange: Optional[pulumi.Input[str]] = None,
             preference: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if exchange is None:
            raise TypeError("Missing 'exchange' argument")
        if preference is None:
            raise TypeError("Missing 'preference' argument")

        _setter("exchange", exchange)
        _setter("preference", preference)

    @property
    @pulumi.getter
    def exchange(self) -> pulumi.Input[str]:
        """
        The mail server responsible for the domain covered by the MX record.
        """
        return pulumi.get(self, "exchange")

    @exchange.setter
    def exchange(self, value: pulumi.Input[str]):
        pulumi.set(self, "exchange", value)

    @property
    @pulumi.getter
    def preference(self) -> pulumi.Input[str]:
        """
        String representing the "preference” value of the MX records. Records with lower preference value take priority.
        """
        return pulumi.get(self, "preference")

    @preference.setter
    def preference(self, value: pulumi.Input[str]):
        pulumi.set(self, "preference", value)


@pulumi.input_type
class SrvRecordRecordArgs:
    def __init__(__self__, *,
                 port: pulumi.Input[int],
                 priority: pulumi.Input[int],
                 target: pulumi.Input[str],
                 weight: pulumi.Input[int]):
        """
        :param pulumi.Input[int] port: Port the service is listening on.
        :param pulumi.Input[int] priority: Priority of the SRV record.
        :param pulumi.Input[str] target: FQDN of the service.
        :param pulumi.Input[int] weight: Weight of the SRV record.
        """
        SrvRecordRecordArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            port=port,
            priority=priority,
            target=target,
            weight=weight,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             port: Optional[pulumi.Input[int]] = None,
             priority: Optional[pulumi.Input[int]] = None,
             target: Optional[pulumi.Input[str]] = None,
             weight: Optional[pulumi.Input[int]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if port is None:
            raise TypeError("Missing 'port' argument")
        if priority is None:
            raise TypeError("Missing 'priority' argument")
        if target is None:
            raise TypeError("Missing 'target' argument")
        if weight is None:
            raise TypeError("Missing 'weight' argument")

        _setter("port", port)
        _setter("priority", priority)
        _setter("target", target)
        _setter("weight", weight)

    @property
    @pulumi.getter
    def port(self) -> pulumi.Input[int]:
        """
        Port the service is listening on.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: pulumi.Input[int]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def priority(self) -> pulumi.Input[int]:
        """
        Priority of the SRV record.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: pulumi.Input[int]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter
    def target(self) -> pulumi.Input[str]:
        """
        FQDN of the service.
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: pulumi.Input[str]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter
    def weight(self) -> pulumi.Input[int]:
        """
        Weight of the SRV record.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: pulumi.Input[int]):
        pulumi.set(self, "weight", value)


@pulumi.input_type
class TxtRecordRecordArgs:
    def __init__(__self__, *,
                 value: pulumi.Input[str]):
        """
        :param pulumi.Input[str] value: The value of the record. Max length: 1024 characters
        """
        TxtRecordRecordArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            value=value,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             value: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if value is None:
            raise TypeError("Missing 'value' argument")

        _setter("value", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        The value of the record. Max length: 1024 characters
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class ZoneSoaRecordArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 expire_time: Optional[pulumi.Input[int]] = None,
                 fqdn: Optional[pulumi.Input[str]] = None,
                 host_name: Optional[pulumi.Input[str]] = None,
                 minimum_ttl: Optional[pulumi.Input[int]] = None,
                 refresh_time: Optional[pulumi.Input[int]] = None,
                 retry_time: Optional[pulumi.Input[int]] = None,
                 serial_number: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 ttl: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] email: The email contact for the SOA record.
        :param pulumi.Input[int] expire_time: The expire time for the SOA record. Defaults to `2419200`.
        :param pulumi.Input[str] host_name: The domain name of the authoritative name server for the SOA record. If not set, computed value from Azure will be used.
        :param pulumi.Input[int] minimum_ttl: The minimum Time To Live for the SOA record. By convention, it is used to determine the negative caching duration. Defaults to `300`.
        :param pulumi.Input[int] refresh_time: The refresh time for the SOA record. Defaults to `3600`.
        :param pulumi.Input[int] retry_time: The retry time for the SOA record. Defaults to `300`.
        :param pulumi.Input[int] serial_number: The serial number for the SOA record. Defaults to `1`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the Record Set.
        :param pulumi.Input[int] ttl: The Time To Live of the SOA Record in seconds. Defaults to `3600`.
        """
        ZoneSoaRecordArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            email=email,
            expire_time=expire_time,
            fqdn=fqdn,
            host_name=host_name,
            minimum_ttl=minimum_ttl,
            refresh_time=refresh_time,
            retry_time=retry_time,
            serial_number=serial_number,
            tags=tags,
            ttl=ttl,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             email: Optional[pulumi.Input[str]] = None,
             expire_time: Optional[pulumi.Input[int]] = None,
             fqdn: Optional[pulumi.Input[str]] = None,
             host_name: Optional[pulumi.Input[str]] = None,
             minimum_ttl: Optional[pulumi.Input[int]] = None,
             refresh_time: Optional[pulumi.Input[int]] = None,
             retry_time: Optional[pulumi.Input[int]] = None,
             serial_number: Optional[pulumi.Input[int]] = None,
             tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
             ttl: Optional[pulumi.Input[int]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if email is None:
            raise TypeError("Missing 'email' argument")
        if expire_time is None and 'expireTime' in kwargs:
            expire_time = kwargs['expireTime']
        if host_name is None and 'hostName' in kwargs:
            host_name = kwargs['hostName']
        if minimum_ttl is None and 'minimumTtl' in kwargs:
            minimum_ttl = kwargs['minimumTtl']
        if refresh_time is None and 'refreshTime' in kwargs:
            refresh_time = kwargs['refreshTime']
        if retry_time is None and 'retryTime' in kwargs:
            retry_time = kwargs['retryTime']
        if serial_number is None and 'serialNumber' in kwargs:
            serial_number = kwargs['serialNumber']

        _setter("email", email)
        if expire_time is not None:
            _setter("expire_time", expire_time)
        if fqdn is not None:
            _setter("fqdn", fqdn)
        if host_name is not None:
            _setter("host_name", host_name)
        if minimum_ttl is not None:
            _setter("minimum_ttl", minimum_ttl)
        if refresh_time is not None:
            _setter("refresh_time", refresh_time)
        if retry_time is not None:
            _setter("retry_time", retry_time)
        if serial_number is not None:
            _setter("serial_number", serial_number)
        if tags is not None:
            _setter("tags", tags)
        if ttl is not None:
            _setter("ttl", ttl)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        """
        The email contact for the SOA record.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> Optional[pulumi.Input[int]]:
        """
        The expire time for the SOA record. Defaults to `2419200`.
        """
        return pulumi.get(self, "expire_time")

    @expire_time.setter
    def expire_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "expire_time", value)

    @property
    @pulumi.getter
    def fqdn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "fqdn")

    @fqdn.setter
    def fqdn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fqdn", value)

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[str]]:
        """
        The domain name of the authoritative name server for the SOA record. If not set, computed value from Azure will be used.
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_name", value)

    @property
    @pulumi.getter(name="minimumTtl")
    def minimum_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The minimum Time To Live for the SOA record. By convention, it is used to determine the negative caching duration. Defaults to `300`.
        """
        return pulumi.get(self, "minimum_ttl")

    @minimum_ttl.setter
    def minimum_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "minimum_ttl", value)

    @property
    @pulumi.getter(name="refreshTime")
    def refresh_time(self) -> Optional[pulumi.Input[int]]:
        """
        The refresh time for the SOA record. Defaults to `3600`.
        """
        return pulumi.get(self, "refresh_time")

    @refresh_time.setter
    def refresh_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "refresh_time", value)

    @property
    @pulumi.getter(name="retryTime")
    def retry_time(self) -> Optional[pulumi.Input[int]]:
        """
        The retry time for the SOA record. Defaults to `300`.
        """
        return pulumi.get(self, "retry_time")

    @retry_time.setter
    def retry_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "retry_time", value)

    @property
    @pulumi.getter(name="serialNumber")
    def serial_number(self) -> Optional[pulumi.Input[int]]:
        """
        The serial number for the SOA record. Defaults to `1`.
        """
        return pulumi.get(self, "serial_number")

    @serial_number.setter
    def serial_number(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "serial_number", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the Record Set.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The Time To Live of the SOA Record in seconds. Defaults to `3600`.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)


